@@ -27,13 +27,13 @@ class AWSStack():
 
 	def start(self):
 		subprocess.run(
-			f'npx cdk bootstrap --app "python -m src.substrate {self.tool.name} -c {self.path} synth"',  # noqa: E501
+			f'npx cdk bootstrap --app "substrate {self.tool.name} -c {self.path} synth"',  # noqa: E501
 			check=True,
 			shell=True
 		)
 
 		subprocess.run(
-			f'npx cdk deploy --require-approval never --app "python -m src.substrate {self.tool.name} -c {self.path} synth"',  # noqa: E501
+			f'npx cdk deploy --require-approval never --app "substrate {self.tool.name} -c {self.path} synth"',  # noqa: E501
 			check=True,
 			shell=True
 		)
@@ -62,7 +62,7 @@ class AWSStack():
 
 	def stop(self):
 		subprocess.run(
-			f'npx cdk destroy --force --app "python -m src.substrate {self.tool.name} -c {self.path} synth"',  # noqa: E501
+			f'npx cdk destroy --force --app "substrate {self.tool.name} -c {self.path} synth"',  # noqa: E501
 			check=True,
 			shell=True
 		)
